/*
 * Main.h
 *
 * RF430FRL152H Sensor Hub Example Project
 *
 * Copyright (C) 2014 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
#ifndef MAIN_H
#define MAIN_H
#include "types.h"


//***************************** FUNCTION PROTOTYPES *************************************/
u08_t DigitalSensorMeasurement ();
void SHT_21_I2C_Master_Measurement(u08_t command, u08_t * rxData);
void DigitalSensorInit();
void ISL29023_I2C_Read(u08_t command, u08_t * rxData);
void ISL29023_I2C_Write(u08_t command, u08_t * rxData);
void ErrataFix();
//***************************** Patch functions ******************************************/
u16_t BlockLockROM_Patched(u16_t blockNumber , u08_t checkLock);
extern void ErrataFix();
typedef void(*DriverFunction)(void);

extern __interrupt void Reset_ISR(void);


//***************************** DEFINES **************************************************/
#define TEMP_MEASURE_HOLD_MASTER	0xE3        				// SHT21 Command for temperature measurement
#define HUMIDITY_HOLD_MEASUREMENT	0xE5        				// SHT21 Command for humidity measurement
#define MASTER_SLAVE_SELECT         BIT7

#define RESULT_MAILBOX   			*((u16_t *)0x1D02)   			// location digital sensor measurement is to be placed in for the ROM code to use it
#define SENSOR_TYPE_MAILBOX   		*((u16_t *)0x1D04)   			// ROM code sets this address to the current digital sensor to be sampled
#define HUMIDITY_SENSOR_ID			BIT1                    		// SHT21 humidity sensor ID bit

//***************************** I2C HAL **************************************************/
#define PORT_I2C_OUT	P1OUT
#define PORT_I2C_DIR	P1DIR
#define PORT_I2C_SEL0	P1SEL0
#define PORT_I2C_SEL1	P1SEL1
#define SDA	BIT0
#define SCL BIT1

#define CLEAR_BLOCK_LOCKS                            	BIT3
#define FRAM_LOCK_BLOCK_AREA_SIZE  						38
#define FRAM_LOCK_BLOCKS								0xF840  //Address of ISO15693 lock blocks

//Firmware System Control Register Settings
#define ROM_EUSCI_SUPPORT_ENABLED       BIT2
#define ROM_EUSCI_SUPPORT_DISABLED      0
#define ROM_SENSOR_SUPPORT_ENABLED      BIT7
#define ROM_SENSOR_SUPPORT_DISABLED     0
#define	NFC_BRIDGE_DISABLED 			BIT6
#define	NFC_BRIDGE_ENABLED  			0
#define	EIGHT_BYTE_BLOCK    			BIT0
#define FOUR_BYTE_BLOCK_MASK			BIT0
#define	FOUR_BYTE_BLOCK     			0
#define	FIRST_ISO_PAGE_MASK    			BIT1
#define	FIRST_ISO_PAGE      			BIT1
#define	SECOND_ISO_PAGE     			0
#define FRAM_BLOCKS_8					0xF3

#define CHECK_LOCK              	1
#define LOCK_BLOCK              	0
#define LOCKED_FLAG                 BIT0

//extern u08_t DS;

//ROM code sensor definitions
enum Sensors_Types
{
    REFERENCE_ADC1_SENSOR          = 0x01,
    THERMISTOR_ADC2_SENSOR         = 0x02,
    ADC0_SENSOR                    = 0x04,
    INTERNAL_SENSOR                = 0x08,
    DIGITAL_SENSOR1                = 0x10,
    DIGITAL_SENSOR2                = 0x20,
    DIGITAL_SENSOR3                = 0x40
};

// ISL29023 register definitions
enum ISL29023_Sensors_Types
{
    ISL29023_COMMAND_I_REGISTER		= 0x00,
    ISL29023_DATA_LSB_REGISTER		= 0x02
};


//***************************** Driver section *******************************************/
#define DRIVER_TABLE_START 				0xFFCE               	// starting address for driver table
#define DRIVER_TABLE_KEY  				0xCECE               	// identifier indicating start and end of driver table
#define DIGITAL_SENSOR_DRIVER_ID       	0x1B00               	// the digital sensor driver identified
#define INIT_DIGITAL_SENSOR_DRIVER_ID  	0x0100               	// the initialize digital sensor driver indentifier

//***************************** Errata Fix Add *******************************************/
#define FIX_ROM_ERRATA  				0x1600     				// the initialize digital sensor driver indentifier
#define BLOCK_LOCK_ID		       		0x2600               	// Block Lock Code for ROM

#define NUMBER_OF_DRIVER_FUNCTIONS 		4                     	// the amount of patched functions

#define DRIVER_1_COMMAND 		(DRIVER_TABLE_START-2)
#define DRIVER_1_ADDR    		(DRIVER_TABLE_START-4)

#define DRIVER_2_COMMAND	   	(DRIVER_TABLE_START-6)
#define DRIVER_2_ADDR        	(DRIVER_TABLE_START-8)

#define DRIVER_3_COMMAND	   	(DRIVER_TABLE_START-10)
#define DRIVER_3_ADDR        	(DRIVER_TABLE_START-12)

#define DRIVER_4_COMMAND	   	(DRIVER_TABLE_START-14)
#define DRIVER_4_ADDR        	(DRIVER_TABLE_START-16)

#define DRIVER_TABLE_END  (DRIVER_TABLE_START-2-(NUMBER_OF_DRIVER_FUNCTIONS*4))

#endif
